@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '1.12.4';
+$Git::Hooks::CheckJira::VERSION = '1.12.5';
 use 5.010;
 use utf8;
 use strict;
@@ -408,7 +408,7 @@ sub notify_affected_refs {
 
     _setup_config($git);
 
-    my $comment = $git->get_config($PKG => 'comment');
+    my $comment = $git->get_config($CFG => 'comment');
 
     return 1 unless defined $comment;
 
@@ -459,7 +459,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 1.12.4
+version 1.12.5
 
 =head1 DESCRIPTION
 
